@@ -189,7 +189,7 @@ vanilla_regions: tuple[RegionData, ...] = (
     RegionData(LogicRegion.traveling_cart_thursday),
     RegionData(LogicRegion.traveling_cart_friday),
     RegionData(LogicRegion.traveling_cart_saturday),
-    RegionData(LogicRegion.raccoon_daddy, (LogicEntrance.buy_from_raccoon, LogicEntrance.can_complete_raccoon_requests_1)),
+    RegionData(LogicRegion.raccoon_daddy, (LogicEntrance.buy_from_raccoon_1, LogicEntrance.can_complete_raccoon_requests_1)),
     RegionData(LogicRegion.raccoon_request_1, (LogicEntrance.can_complete_raccoon_requests_2,)),
     RegionData(LogicRegion.raccoon_request_2, (LogicEntrance.can_complete_raccoon_requests_3,)),
     RegionData(LogicRegion.raccoon_request_3, (LogicEntrance.can_complete_raccoon_requests_4,)),
@@ -198,7 +198,12 @@ vanilla_regions: tuple[RegionData, ...] = (
     RegionData(LogicRegion.raccoon_request_6, (LogicEntrance.can_complete_raccoon_requests_7,)),
     RegionData(LogicRegion.raccoon_request_7, (LogicEntrance.can_complete_raccoon_requests_8,)),
     RegionData(LogicRegion.raccoon_request_8),
-    RegionData(LogicRegion.raccoon_shop),
+    RegionData(LogicRegion.raccoon_shop_1, (LogicEntrance.buy_from_raccoon_2,)),
+    RegionData(LogicRegion.raccoon_shop_2, (LogicEntrance.buy_from_raccoon_3,)),
+    RegionData(LogicRegion.raccoon_shop_3, (LogicEntrance.buy_from_raccoon_4,)),
+    RegionData(LogicRegion.raccoon_shop_4, (LogicEntrance.buy_from_raccoon_5,)),
+    RegionData(LogicRegion.raccoon_shop_5, (LogicEntrance.buy_from_raccoon_6,)),
+    RegionData(LogicRegion.raccoon_shop_6),
 
     RegionData(LogicRegion.egg_festival),
     RegionData(LogicRegion.desert_festival),
@@ -460,7 +465,12 @@ vanilla_connections: tuple[ConnectionData, ...] = (
     ConnectionData(LogicEntrance.can_complete_raccoon_requests_7, LogicRegion.raccoon_request_7),
     ConnectionData(LogicEntrance.can_complete_raccoon_requests_8, LogicRegion.raccoon_request_8),
     ConnectionData(LogicEntrance.fish_in_waterfall, LogicRegion.forest_waterfall),
-    ConnectionData(LogicEntrance.buy_from_raccoon, LogicRegion.raccoon_shop),
+    ConnectionData(LogicEntrance.buy_from_raccoon_1, LogicRegion.raccoon_shop_1),
+    ConnectionData(LogicEntrance.buy_from_raccoon_2, LogicRegion.raccoon_shop_2),
+    ConnectionData(LogicEntrance.buy_from_raccoon_3, LogicRegion.raccoon_shop_3),
+    ConnectionData(LogicEntrance.buy_from_raccoon_4, LogicRegion.raccoon_shop_4),
+    ConnectionData(LogicEntrance.buy_from_raccoon_5, LogicRegion.raccoon_shop_5),
+    ConnectionData(LogicEntrance.buy_from_raccoon_6, LogicRegion.raccoon_shop_6),
     ConnectionData(LogicEntrance.farmhouse_cooking, LogicRegion.kitchen),
     ConnectionData(LogicEntrance.watch_queen_of_sauce, LogicRegion.queen_of_sauce),
 
